---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

Thank you for contributing to the project!
We recommend you check out our ["Contributing to the SAFE Network"](https://github.com/maidsafe/QA/blob/master/CONTRIBUTING.md) guide if you haven't already.

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior, e.g.:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information where applicable):**
 - OS: [e.g. Ubuntu 18.04]
 - Shell: [e.g. Zsh]
 - Rust: [e.g. 1.42.0 stable]
 - bls-dkg crate version [e.g. 0.1.0]
 - etc

**Additional context**
Add any other context about the problem here.
